@@ -195,14 +195,18 @@ REST_API_VERSION_HISTORY = """
     * 2.76 - Added 'default_ad_site' field in security service object.
     * 2.77 - Added support for share transfer between different projects.
     * 2.78 - Added Share Network Subnet Metadata to Metadata API.
-
+    * 2.79 - Added ``with_count`` in share snapshot list API to get total
+             count info.
+    * 2.80 - Added share backup APIs.
+    * 2.81 - Added API methods, endpoint /resource-locks.
+    * 2.82 - Added lock and restriction to share access rules.
 """
 
 # The minimum and maximum versions of the API supported
 # The default api version request is defined to be the
 # minimum version of the API supported.
 _MIN_API_VERSION = "2.0"
-_MAX_API_VERSION = "2.78"
+_MAX_API_VERSION = "2.82"
 DEFAULT_API_VERSION = _MIN_API_VERSION
 
 
