@@ -29,7 +29,9 @@ from manila.api.views import share_snapshots as snapshot_views
 from manila import db
 from manila import exception
 from manila.i18n import _
+from manila import policy
 from manila import share
+from manila import utils
 
 LOG = log.getLogger(__name__)
 
@@ -66,6 +68,7 @@ class ShareSnapshotMixin(object):
         context = req.environ['manila.context']
 
         LOG.info("Delete snapshot with id: %s", id, context=context)
+        policy.check_policy(context, 'share', 'delete_snapshot')
 
         try:
             snapshot = self.share_api.get_snapshot(context, id)
@@ -100,6 +103,13 @@ class ShareSnapshotMixin(object):
         # Remove keys that are not related to share attrs
         search_opts.pop('limit', None)
         search_opts.pop('offset', None)
+
+        show_count = False
+        if 'with_count' in search_opts:
+            show_count = utils.get_bool_from_api_params(
+                'with_count', search_opts)
+            search_opts.pop('with_count')
+
         sort_key, sort_dir = common.get_sort_params(search_opts)
         key_dict = {"name": "display_name",
                     "description": "display_description"}
@@ -137,19 +147,23 @@ class ShareSnapshotMixin(object):
         common.remove_invalid_options(context, search_opts,
                                       self._get_snapshots_search_options())
 
-        snapshots = self.share_api.get_all_snapshots(
-            context,
-            search_opts=search_opts,
-            limit=limit,
-            offset=offset,
-            sort_key=sort_key,
-            sort_dir=sort_dir,
-        )
+        total_count = None
+        if show_count:
+            count, snapshots = self.share_api.get_all_snapshots_with_count(
+                context, search_opts=search_opts, limit=limit, offset=offset,
+                sort_key=sort_key, sort_dir=sort_dir)
+            total_count = count
+        else:
+            snapshots = self.share_api.get_all_snapshots(
+                context, search_opts=search_opts, limit=limit, offset=offset,
+                sort_key=sort_key, sort_dir=sort_dir)
 
         if is_detail:
-            snapshots = self._view_builder.detail_list(req, snapshots)
+            snapshots = self._view_builder.detail_list(
+                req, snapshots, total_count)
         else:
-            snapshots = self._view_builder.summary_list(req, snapshots)
+            snapshots = self._view_builder.summary_list(
+                req, snapshots, total_count)
         return snapshots
 
     def _get_snapshots_search_options(self):
@@ -160,6 +174,7 @@ class ShareSnapshotMixin(object):
     def update(self, req, id, body):
         """Update a snapshot."""
         context = req.environ['manila.context']
+        policy.check_policy(context, 'share', 'snapshot_update')
 
         if not body or 'snapshot' not in body:
             raise exc.HTTPUnprocessableEntity()
@@ -174,6 +189,11 @@ class ShareSnapshotMixin(object):
                        for key in valid_update_keys
                        if key in snapshot_data}
 
+        common.check_display_field_length(
+            update_dict.get('display_name'), 'display_name')
+        common.check_display_field_length(
+            update_dict.get('display_description'), 'display_description')
+
         try:
             snapshot = self.share_api.get_snapshot(context, id)
         except exception.NotFound:
@@ -218,12 +238,16 @@ class ShareSnapshotMixin(object):
         # NOTE(rushiagr): v2 API allows name instead of display_name
         if 'name' in snapshot:
             snapshot['display_name'] = snapshot.get('name')
+            common.check_display_field_length(
+                snapshot['display_name'], 'name')
             del snapshot['name']
 
         # NOTE(rushiagr): v2 API allows description instead of
         #                display_description
         if 'description' in snapshot:
             snapshot['display_description'] = snapshot.get('description')
+            common.check_display_field_length(
+                snapshot['display_description'], 'description')
             del snapshot['description']
 
         kwargs = {}
