@@ -52,6 +52,7 @@ class ShareMixin(object):
     def _delete(self, *args, **kwargs):
         return self.share_api.delete(*args, **kwargs)
 
+    @wsgi.Controller.authorize('get')
     def show(self, req, id):
         """Return data about the given share."""
         context = req.environ['manila.context']
@@ -63,6 +64,7 @@ class ShareMixin(object):
 
         return self._view_builder.detail(req, share)
 
+    @wsgi.Controller.authorize
     def delete(self, req, id):
         """Delete a share."""
         context = req.environ['manila.context']
@@ -97,6 +99,7 @@ class ShareMixin(object):
 
         return webob.Response(status_int=http_client.ACCEPTED)
 
+    @wsgi.Controller.authorize("get_all")
     def index(self, req):
         """Returns a summary list of shares."""
         req.GET.pop('export_location_id', None)
@@ -107,6 +110,7 @@ class ShareMixin(object):
         req.GET.pop('with_count', None)
         return self._get_shares(req, is_detail=False)
 
+    @wsgi.Controller.authorize("get_all")
     def detail(self, req):
         """Returns a detailed list of shares."""
         req.GET.pop('export_location_id', None)
@@ -659,6 +663,7 @@ class ShareMixin(object):
 
         return self._access_view_builder.list_view(req, access_rules)
 
+    @wsgi.Controller.authorize("extend")
     def _extend(self, req, id, body):
         """Extend size of a share."""
         context = req.environ['manila.context']
@@ -679,6 +684,7 @@ class ShareMixin(object):
 
         return webob.Response(status_int=http_client.ACCEPTED)
 
+    @wsgi.Controller.authorize("shrink")
     def _shrink(self, req, id, body):
         """Shrink size of a share."""
         context = req.environ['manila.context']
