@@ -16,6 +16,9 @@
 # The maximum value a signed INT type may have
 DB_MAX_INT = 0x7FFFFFFF
 
+# The maximum length a display field may have
+DB_DISPLAY_FIELDS_MAX_LENGTH = 255
+
 # SHARE AND GENERAL STATUSES
 STATUS_CREATING = 'creating'
 STATUS_CREATING_FROM_SNAPSHOT = 'creating_from_snapshot'
@@ -45,9 +48,13 @@ STATUS_RESTORING = 'restoring'
 STATUS_REVERTING = 'reverting'
 STATUS_REVERTING_ERROR = 'reverting_error'
 STATUS_AWAITING_TRANSFER = 'awaiting_transfer'
+STATUS_BACKUP_CREATING = 'backup_creating'
+STATUS_BACKUP_RESTORING = 'backup_restoring'
+STATUS_BACKUP_RESTORING_ERROR = 'backup_restoring_error'
 
 # Transfer resource type
 SHARE_RESOURCE_TYPE = 'share'
+SHARE_ACCESS_RESOURCE_TYPE = 'access_rule'
 
 # Access rule states
 ACCESS_STATE_QUEUED_TO_APPLY = 'queued_to_apply'
@@ -133,6 +140,7 @@ TRANSITIONAL_STATUSES = (
     STATUS_MIGRATING, STATUS_MIGRATING_TO,
     STATUS_RESTORING, STATUS_REVERTING,
     STATUS_SERVER_MIGRATING, STATUS_SERVER_MIGRATING_TO,
+    STATUS_BACKUP_RESTORING, STATUS_BACKUP_CREATING,
 )
 
 INVALID_SHARE_INSTANCE_STATUSES_FOR_ACCESS_RULE_UPDATES = (
@@ -245,6 +253,44 @@ REPLICATION_TYPE_WRITABLE = 'writable'
 REPLICATION_TYPE_DR = 'dr'
 
 
+POLICY_EXTEND_BEYOND_MAX_SHARE_SIZE = 'extend_beyond_max_share_size_spec'
+
+RESOURCE_ACTION_DELETE = 'delete'  # delete, soft-delete, unmanage
+RESOURCE_ACTION_SHOW = 'show'
+
+RESOURCE_LOCK_RESOURCE_TYPES = (
+    SHARE_RESOURCE_TYPE,
+    SHARE_ACCESS_RESOURCE_TYPE,
+)
+
+RESOURCE_LOCK_RESOURCE_ACTIONS = (
+    RESOURCE_ACTION_DELETE,
+    RESOURCE_ACTION_SHOW,
+)
+
+RESOURCE_LOCK_ACTIONS_MAPPING = {
+    "share": [RESOURCE_ACTION_DELETE],
+    "access_rule": [RESOURCE_ACTION_DELETE, RESOURCE_ACTION_SHOW],
+}
+
+DISALLOWED_STATUS_WHEN_LOCKING_SHARES = (
+    STATUS_DELETING,
+    STATUS_ERROR_DELETING,
+    STATUS_UNMANAGING,
+    STATUS_MANAGE_ERROR_UNMANAGING,
+    STATUS_UNMANAGE_ERROR,
+    STATUS_UNMANAGED,  # not possible, future proofing
+    STATUS_DELETED,  # not possible, future proofing
+)
+
+DISALLOWED_STATUS_WHEN_LOCKING_ACCESS_RULES = (
+    ACCESS_STATE_QUEUED_TO_DENY,
+    ACCESS_STATE_DENYING,
+    ACCESS_STATE_ERROR,
+    ACCESS_STATE_DELETED,
+)
+
+
 class ExtraSpecs(object):
 
     # Extra specs key names
@@ -257,6 +303,7 @@ class ExtraSpecs(object):
     AVAILABILITY_ZONES = "availability_zones"
     PROVISIONING_MAX_SHARE_SIZE = "provisioning:max_share_size"
     PROVISIONING_MIN_SHARE_SIZE = "provisioning:min_share_size"
+    PROVISIONING_MAX_SHARE_EXTEND_SIZE = "provisioning:max_share_extend_size"
 
     # Extra specs containers
     REQUIRED = (
@@ -271,7 +318,8 @@ class ExtraSpecs(object):
         MOUNT_SNAPSHOT_SUPPORT,
         AVAILABILITY_ZONES,
         PROVISIONING_MAX_SHARE_SIZE,
-        PROVISIONING_MIN_SHARE_SIZE
+        PROVISIONING_MIN_SHARE_SIZE,
+        PROVISIONING_MAX_SHARE_EXTEND_SIZE
     )
 
     # NOTE(cknight): Some extra specs are necessary parts of the Manila API and
@@ -304,7 +352,7 @@ class AdminOnlyMetadata(object):
     AFFINITY_KEY = "__affinity_same_host"
     ANTI_AFFINITY_KEY = "__affinity_different_host"
 
-    SCHEDULER_FILTERS = [
+    SCHEDULER_FILTERS = (
         AFFINITY_KEY,
-        ANTI_AFFINITY_KEY,
-    ]
+        ANTI_AFFINITY_KEY
+    )
