@@ -57,6 +57,9 @@ db_opts = [
                default='share-snapshot-%s',
                help='Template string to be used to generate share snapshot '
                     'names.'),
+    cfg.StrOpt('share_backup_name_template',
+               default='share-backup-%s',
+               help='Template string to be used to generate backup names.'),
 ]
 
 CONF = cfg.CONF
@@ -494,6 +497,58 @@ def share_restore(context, share_id):
 ###################
 
 
+def share_transfer_get(context, transfer_id):
+    """Get a share transfer record or raise if it does not exist."""
+    return IMPL.share_transfer_get(context, transfer_id)
+
+
+def transfer_get_all(context, limit=None, sort_key=None,
+                     sort_dir=None, filters=None, offset=None):
+    """Get all share transfer records."""
+    return IMPL.transfer_get_all(context, limit=limit,
+                                 sort_key=sort_key, sort_dir=sort_dir,
+                                 filters=filters, offset=offset)
+
+
+def transfer_get_all_by_project(context, project_id,
+                                limit=None, sort_key=None,
+                                sort_dir=None, filters=None, offset=None):
+    """Get all share transfer records for specified project."""
+    return IMPL.transfer_get_all_by_project(context, project_id,
+                                            limit=limit, sort_key=sort_key,
+                                            sort_dir=sort_dir,
+                                            filters=filters, offset=offset)
+
+
+def transfer_create(context, values):
+    """Create an entry in the transfers table."""
+    return IMPL.transfer_create(context, values)
+
+
+def transfer_destroy(context, transfer_id, update_share_status=True):
+    """Destroy a record in the share transfer table."""
+    return IMPL.transfer_destroy(context, transfer_id,
+                                 update_share_status=update_share_status)
+
+
+def transfer_accept(context, transfer_id, user_id, project_id,
+                    accept_snapshots=False):
+    """Accept a share transfer."""
+    return IMPL.transfer_accept(context, transfer_id, user_id, project_id,
+                                accept_snapshots=accept_snapshots)
+
+
+def transfer_accept_rollback(context, transfer_id, user_id,
+                             project_id, rollback_snap=False):
+    """Rollback a share transfer."""
+    return IMPL.transfer_accept_rollback(context, transfer_id,
+                                         user_id, project_id,
+                                         rollback_snap=rollback_snap)
+
+
+###################
+
+
 def share_access_create(context, values):
     """Allow access to share."""
     return IMPL.share_access_create(context, values)
@@ -504,6 +559,11 @@ def share_access_get(context, access_id):
     return IMPL.share_access_get(context, access_id)
 
 
+def share_access_get_with_context(context, access_id):
+    """Get share access rule."""
+    return IMPL.share_access_get_with_context(context, access_id)
+
+
 def share_access_get_all_for_share(context, share_id, filters=None):
     """Get all access rules for given share."""
     return IMPL.share_access_get_all_for_share(context, share_id,
@@ -626,9 +686,10 @@ def share_snapshot_create(context, values):
     return IMPL.share_snapshot_create(context, values)
 
 
-def share_snapshot_get(context, snapshot_id):
+def share_snapshot_get(context, snapshot_id, project_only=True):
     """Get a snapshot or raise if it does not exist."""
-    return IMPL.share_snapshot_get(context, snapshot_id)
+    return IMPL.share_snapshot_get(context, snapshot_id,
+                                   project_only=project_only)
 
 
 def share_snapshot_get_all(context, filters=None, limit=None, offset=None,
@@ -639,6 +700,15 @@ def share_snapshot_get_all(context, filters=None, limit=None, offset=None,
         sort_key=sort_key, sort_dir=sort_dir)
 
 
+def share_snapshot_get_all_with_count(context, filters=None, limit=None,
+                                      offset=None, sort_key=None,
+                                      sort_dir=None):
+    """Get all snapshots."""
+    return IMPL.share_snapshot_get_all_with_count(
+        context, filters=filters, limit=limit, offset=offset,
+        sort_key=sort_key, sort_dir=sort_dir)
+
+
 def share_snapshot_get_all_by_project(context, project_id, filters=None,
                                       limit=None, offset=None, sort_key=None,
                                       sort_dir=None):
@@ -648,6 +718,16 @@ def share_snapshot_get_all_by_project(context, project_id, filters=None,
         sort_key=sort_key, sort_dir=sort_dir)
 
 
+def share_snapshot_get_all_by_project_with_count(context, project_id,
+                                                 filters=None, limit=None,
+                                                 offset=None, sort_key=None,
+                                                 sort_dir=None):
+    """Get all snapshots belonging to a project."""
+    return IMPL.share_snapshot_get_all_by_project_with_count(
+        context, project_id, filters=filters, limit=limit, offset=offset,
+        sort_key=sort_key, sort_dir=sort_dir)
+
+
 def share_snapshot_get_all_for_share(context, share_id, filters=None,
                                      sort_key=None, sort_dir=None):
     """Get all snapshots for a share."""
@@ -761,7 +841,42 @@ def share_snapshot_instance_export_location_delete(context, el_id):
     return IMPL.share_snapshot_instance_export_location_delete(context, el_id)
 
 
+####################
+
+def share_snapshot_metadata_get(context, share_snapshot_id, **kwargs):
+    """Get all metadata for a share snapshot."""
+    return IMPL.share_snapshot_metadata_get(context,
+                                            share_snapshot_id,
+                                            **kwargs)
+
+
+def share_snapshot_metadata_get_item(context, share_snapshot_id, key):
+    """Get metadata item for a share snapshot."""
+    return IMPL.share_snapshot_metadata_get_item(context,
+                                                 share_snapshot_id, key)
+
+
+def share_snapshot_metadata_delete(context, share_snapshot_id, key):
+    """Delete the given metadata item."""
+    IMPL.share_snapshot_metadata_delete(context, share_snapshot_id, key)
+
+
+def share_snapshot_metadata_update(context, share_snapshot_id,
+                                   metadata, delete):
+    """Update metadata if it exists, otherwise create it."""
+    return IMPL.share_snapshot_metadata_update(context, share_snapshot_id,
+                                               metadata, delete)
+
+
+def share_snapshot_metadata_update_item(context, share_snapshot_id,
+                                        metadata):
+    """Update metadata item if it exists, otherwise create it."""
+    return IMPL.share_snapshot_metadata_update_item(context,
+                                                    share_snapshot_id,
+                                                    metadata)
 ###################
+
+
 def security_service_create(context, values):
     """Create security service DB record."""
     return IMPL.security_service_create(context, values)
@@ -792,6 +907,12 @@ def security_service_get_all_by_project(context, project_id):
     return IMPL.security_service_get_all_by_project(context, project_id)
 
 
+def security_service_get_all_by_share_network(context, share_network_id):
+    """Get all security service DB records for the given share network."""
+    return IMPL.security_service_get_all_by_share_network(context,
+                                                          share_network_id)
+
+
 ####################
 def share_metadata_get(context, share_id):
     """Get all metadata for a share."""
@@ -953,13 +1074,6 @@ def share_network_update_security_service(context, id,
         context, id, current_security_service_id, new_security_service_id)
 
 
-def count_share_networks(context, project_id, user_id=None,
-                         share_type_id=None, session=None):
-    return IMPL.count_share_networks(
-        context, project_id, user_id=user_id, share_type_id=share_type_id,
-        session=session,
-    )
-
 ##################
 
 
@@ -978,17 +1092,20 @@ def share_network_subnet_update(context, network_subnet_id, values):
     return IMPL.share_network_subnet_update(context, network_subnet_id, values)
 
 
-def share_network_subnet_get(context, network_subnet_id, session=None):
+def share_network_subnet_get(context, network_subnet_id, parent_id=None):
     """Get requested share network subnet DB record."""
-    return IMPL.share_network_subnet_get(context, network_subnet_id,
-                                         session=session)
+    return IMPL.share_network_subnet_get(
+        context,
+        network_subnet_id,
+        parent_id=parent_id,
+    )
 
 
-def share_network_subnet_get_all_with_same_az(context, network_subnet_id,
-                                              session=None):
+def share_network_subnet_get_all_with_same_az(context, network_subnet_id):
     """Get requested az share network subnets DB record."""
     return IMPL.share_network_subnet_get_all_with_same_az(
-        context, network_subnet_id, session=session)
+        context, network_subnet_id,
+    )
 
 
 def share_network_subnet_get_all(context):
@@ -997,8 +1114,9 @@ def share_network_subnet_get_all(context):
 
 
 def share_network_subnets_get_all_by_availability_zone_id(
-        context, share_network_id, availability_zone_id,
-        fallback_to_default=True):
+    context, share_network_id, availability_zone_id,
+    fallback_to_default=True,
+):
     """Get the share network subnets DB record in a given AZ.
 
     This method returns list of subnets DB record for a given share network id
@@ -1010,22 +1128,64 @@ def share_network_subnets_get_all_by_availability_zone_id(
     """
     return IMPL.share_network_subnets_get_all_by_availability_zone_id(
         context, share_network_id, availability_zone_id,
-        fallback_to_default=fallback_to_default)
+        fallback_to_default=fallback_to_default,
+    )
 
 
 def share_network_subnet_get_default_subnets(context, share_network_id):
     """Get the default share network subnets DB records."""
-    return IMPL.share_network_subnet_get_default_subnets(context,
-                                                         share_network_id)
+    return IMPL.share_network_subnet_get_default_subnets(
+        context, share_network_id,
+    )
 
 
 def share_network_subnet_get_all_by_share_server_id(context, share_server_id):
     """Get the subnets that are being used by the share server."""
     return IMPL.share_network_subnet_get_all_by_share_server_id(
-        context, share_server_id)
+        context, share_server_id,
+    )
+
+####################
 
 
-##################
+def share_network_subnet_metadata_get(context, share_network_subnet_id,
+                                      **kwargs):
+    """Get all metadata for a share network subnet."""
+    return IMPL.share_network_subnet_metadata_get(context,
+                                                  share_network_subnet_id,
+                                                  **kwargs)
+
+
+def share_network_subnet_metadata_get_item(context, share_network_subnet_id,
+                                           key):
+    """Get metadata item for a share network subnet."""
+    return IMPL.share_network_subnet_metadata_get_item(context,
+                                                       share_network_subnet_id,
+                                                       key)
+
+
+def share_network_subnet_metadata_delete(context, share_network_subnet_id,
+                                         key):
+    """Delete the given metadata item."""
+    IMPL.share_network_subnet_metadata_delete(context, share_network_subnet_id,
+                                              key)
+
+
+def share_network_subnet_metadata_update(context, share_network_subnet_id,
+                                         metadata, delete):
+    """Update metadata if it exists, otherwise create it."""
+    return IMPL.share_network_subnet_metadata_update(context,
+                                                     share_network_subnet_id,
+                                                     metadata, delete)
+
+
+def share_network_subnet_metadata_update_item(context, share_network_subnet_id,
+                                              metadata):
+    """Update metadata item if it exists, otherwise create it."""
+    return IMPL.share_network_subnet_metadata_update_item(
+        context, share_network_subnet_id, metadata)
+
+###################
 
 
 def network_allocation_create(context, values):
@@ -1044,19 +1204,18 @@ def network_allocation_update(context, id, values, read_deleted=None):
                                           read_deleted=read_deleted)
 
 
-def network_allocation_get(context, id, session=None, read_deleted=None):
+def network_allocation_get(context, id, read_deleted=None):
     """Get a network allocation DB record."""
-    return IMPL.network_allocation_get(context, id, session,
-                                       read_deleted=read_deleted)
+    return IMPL.network_allocation_get(context, id, read_deleted=read_deleted)
 
 
-def network_allocations_get_for_share_server(context, share_server_id,
-                                             session=None, label=None,
-                                             subnet_id=None):
+def network_allocations_get_for_share_server(
+    context, share_server_id, label=None, subnet_id=None,
+):
     """Get network allocations for share server."""
     return IMPL.network_allocations_get_for_share_server(
-        context, share_server_id, label=label, session=session,
-        subnet_id=subnet_id)
+        context, share_server_id, label=label, subnet_id=subnet_id,
+    )
 
 
 def network_allocations_get_by_ip_address(context, ip_address):
@@ -1082,31 +1241,34 @@ def share_server_update(context, id, values):
     return IMPL.share_server_update(context, id, values)
 
 
-def share_server_get(context, id, session=None):
+def share_server_get(context, id):
     """Get share server DB record by ID."""
-    return IMPL.share_server_get(context, id, session=session)
+    return IMPL.share_server_get(context, id)
 
 
-def share_server_search_by_identifier(context, identifier, session=None):
+def share_server_search_by_identifier(context, identifier):
     """Search for share servers based on given identifier."""
     return IMPL.share_server_search_by_identifier(
-        context, identifier, session=session)
+        context, identifier,
+    )
 
 
-def share_server_get_all_by_host_and_share_subnet_valid(context, host,
-                                                        share_subnet_id,
-                                                        session=None):
+def share_server_get_all_by_host_and_share_subnet_valid(
+    context, host, share_subnet_id,
+):
     """Get share server DB records by host and share net not error."""
     return IMPL.share_server_get_all_by_host_and_share_subnet_valid(
-        context, host, share_subnet_id, session=session)
+        context, host, share_subnet_id,
+    )
 
 
-def share_server_get_all_by_host_and_share_subnet(context, host,
-                                                  share_subnet_id,
-                                                  session=None):
+def share_server_get_all_by_host_and_share_subnet(
+    context, host, share_subnet_id,
+):
     """Get share server DB records by host and share net."""
     return IMPL.share_server_get_all_by_host_and_share_subnet(
-        context, host, share_subnet_id, session=session)
+        context, host, share_subnet_id,
+    )
 
 
 def share_server_get_all(context):
@@ -1135,6 +1297,11 @@ def get_all_expired_shares(context):
     return IMPL.get_all_expired_shares(context)
 
 
+def get_all_expired_transfers(context):
+    """Get all expired transfers DB records."""
+    return IMPL.get_all_expired_transfers(context)
+
+
 def share_server_backend_details_set(context, share_server_id, server_details):
     """Create DB record with backend details."""
     return IMPL.share_server_backend_details_set(context, share_server_id,
@@ -1353,14 +1520,12 @@ def count_share_group_snapshots_in_share_group(context, share_group_id):
         context, share_group_id)
 
 
-def count_share_groups_in_share_network(context, share_network_id,
-                                        session=None):
+def count_share_groups_in_share_network(context, share_network_id):
     """Return the number of groups with the specified share network."""
     return IMPL.count_share_groups_in_share_network(context, share_network_id)
 
 
-def count_share_group_snapshot_members_in_share(context, share_id,
-                                                session=None):
+def count_share_group_snapshot_members_in_share(context, share_id):
     """Returns the number of group snapshot members linked to the share."""
     return IMPL.count_share_group_snapshot_members_in_share(context, share_id)
 
@@ -1632,3 +1797,60 @@ def async_operation_data_update(context, entity_id, details,
 def async_operation_data_delete(context, entity_id, key=None):
     """Remove one, list or all key-value pairs for given entity_id."""
     return IMPL.async_operation_data_delete(context, entity_id, key)
+
+####################
+
+
+def share_backup_create(context, share_id, values):
+    """Create new share backup with specified values."""
+    return IMPL.share_backup_create(context, share_id, values)
+
+
+def share_backup_update(context, backup_id, values):
+    """Updates a share backup with given values."""
+    return IMPL.share_backup_update(context, backup_id, values)
+
+
+def share_backup_get(context, backup_id):
+    """Get share backup by id."""
+    return IMPL.share_backup_get(context, backup_id)
+
+
+def share_backups_get_all(context, filters=None, limit=None, offset=None,
+                          sort_key=None, sort_dir=None):
+    """Get all backups."""
+    return IMPL.share_backups_get_all(
+        context, filters=filters, limit=limit, offset=offset,
+        sort_key=sort_key, sort_dir=sort_dir)
+
+
+def share_backup_delete(context, backup_id):
+    """Deletes backup with the specified ID."""
+    return IMPL.share_backup_delete(context, backup_id)
+
+#####################
+
+
+def resource_lock_create(context, values):
+    """Create a resource lock."""
+    return IMPL.resource_lock_create(context, values)
+
+
+def resource_lock_update(context, lock_id, values):
+    """Update a resource lock."""
+    return IMPL.resource_lock_update(context, lock_id, values)
+
+
+def resource_lock_delete(context, lock_id):
+    """Delete a resource lock."""
+    return IMPL.resource_lock_delete(context, lock_id)
+
+
+def resource_lock_get(context, lock_id):
+    """Retrieve a resource lock."""
+    return IMPL.resource_lock_get(context, lock_id)
+
+
+def resource_lock_get_all(context, **kwargs):
+    """Retrieve all resource locks."""
+    return IMPL.resource_lock_get_all(context, **kwargs)
