@@ -25,7 +25,9 @@ import manila.common.config
 import manila.compute
 import manila.compute.nova
 import manila.coordination
+import manila.data.drivers.nfs
 import manila.data.helper
+import manila.data.manager
 import manila.db.api
 import manila.db.base
 import manila.exception
@@ -72,6 +74,7 @@ import manila.share.drivers.infortrend.driver
 import manila.share.drivers.inspur.as13000.as13000_nas
 import manila.share.drivers.inspur.instorage.instorage
 import manila.share.drivers.lvm
+import manila.share.drivers.macrosan.macrosan_nas
 import manila.share.drivers.maprfs.maprfs_native
 import manila.share.drivers.netapp.options
 import manila.share.drivers.nexenta.options
@@ -103,7 +106,10 @@ _global_opt_lists = [
     manila.common.config.global_opts,
     manila.compute._compute_opts,
     manila.coordination.coordination_opts,
+    manila.data.drivers.nfs.nfsbackup_service_opts,
     manila.data.helper.data_helper_opts,
+    manila.data.manager.backup_opts,
+    manila.data.manager.data_opts,
     manila.db.api.db_opts,
     [manila.db.base.db_driver_opt],
     manila.exception.exc_log_opts,
@@ -160,6 +166,7 @@ _global_opt_lists = [
     manila.share.drivers.infortrend.driver.infortrend_nas_opts,
     manila.share.drivers.inspur.as13000.as13000_nas.inspur_as13000_opts,
     manila.share.drivers.inspur.instorage.instorage.instorage_opts,
+    manila.share.drivers.macrosan.macrosan_nas.macrosan_opts,
     manila.share.drivers.maprfs.maprfs_native.maprfs_native_share_opts,
     manila.share.drivers.lvm.share_opts,
     manila.share.drivers.netapp.options.netapp_proxy_opts,
