@@ -41,7 +41,8 @@ EMC_NAS_OPTS = [
                 help='Use secure connection to server.'),
     cfg.StrOpt('emc_share_backend',
                ignore_case=True,
-               choices=['isilon', 'vnx', 'unity', 'vmax', 'powermax'],
+               choices=['isilon', 'vnx', 'unity', 'vmax', 'powermax',
+                        'powerstore', 'powerflex'],
                help='Share backend.'),
     cfg.StrOpt('emc_nas_root_dir',
                help='The root directory where shares will be located.'),
@@ -81,9 +82,11 @@ class EMCShareDriver(driver.ShareDriver):
                         "OpenStack. After that, only "
                         "'emc_share_backend=powermax' will be excepted.")
             self.backend_name = 'powermax'
+        LOG.info("BACKEND IS: %s", self.backend_name)
         self.plugin = self.plugin_manager.load_plugin(
             self.backend_name,
             configuration=self.configuration)
+        LOG.info(f"PLUGIN HAS: {self.plugin.__dict__}")
         super(EMCShareDriver, self).__init__(
             self.plugin.driver_handles_share_servers, *args, **kwargs)
 
@@ -258,8 +261,8 @@ class EMCShareDriver(driver.ShareDriver):
     def update_access(self, context, share, access_rules, add_rules,
                       delete_rules, share_server=None):
         """Update access to the share."""
-        self.plugin.update_access(context, share, access_rules, add_rules,
-                                  delete_rules, share_server)
+        return self.plugin.update_access(context, share, access_rules,
+                                         add_rules, delete_rules, share_server)
 
     def check_for_setup_error(self):
         """Check for setup error."""
@@ -283,6 +286,7 @@ class EMCShareDriver(driver.ShareDriver):
             revert_to_snapshot_support=self.revert_to_snap_support)
         self.plugin.update_share_stats(data)
         super(EMCShareDriver, self)._update_share_stats(data)
+        LOG.info(f"Updated share stats: {self._stats}")
 
     def get_network_allocations_number(self):
         """Returns number of network allocations for creating VIFs."""
