@@ -190,6 +190,14 @@ netapp_provisioning_opts = [
                default=60,  # Default to one minutes
                help='Sets maximum amount of time in seconds to wait for a '
                     'synchronous ONTAP REST API operation to be completed.'),
+    cfg.IntOpt('netapp_security_cert_expire_days',
+               min=1,
+               max=3652,
+               default=365,
+               help='Defines the expiration time (in days) for the '
+                    'certificate created during the vserver creation.  This '
+                    'option only applies when the option '
+                    'driver_handles_share_servers is set to True.'),
 ]
 
 netapp_cluster_opts = [
@@ -200,7 +208,12 @@ netapp_cluster_opts = [
                      'option should only be specified when the option '
                      'driver_handles_share_servers is set to False (i.e. the '
                      'driver is managing shares on a single pre-configured '
-                     'Vserver).')), ]
+                     'Vserver).')),
+    cfg.StrOpt('netapp_cluster_name',
+               help=('This option specifies the Cluster Name on which '
+                     'provisioning of file storage shares should occur. '
+                     'If not set, the driver will try to discover by '
+                     'API call.')), ]
 
 netapp_support_opts = [
     cfg.StrOpt('netapp_trace_flags',
