@@ -24,6 +24,7 @@ inline callbacks.
 import os
 import shutil
 from unittest import mock
+import warnings
 
 import fixtures
 from oslo_concurrency import lockutils
@@ -33,6 +34,7 @@ import oslo_messaging
 from oslo_messaging import conffixture as messaging_conffixture
 from oslo_utils import uuidutils
 import oslotest.base as base_test
+from sqlalchemy import exc as sqla_exc
 
 from manila.api.openstack import api_version_request as api_version
 from manila import coordination
@@ -60,7 +62,7 @@ CONF.register_opts(test_opts)
 _DB_CACHE = None
 
 
-class Database(fixtures.Fixture):
+class DatabaseFixture(fixtures.Fixture):
 
     def __init__(self, db_session, db_migrate, sql_connection, sqlite_db,
                  sqlite_clean_db):
@@ -70,6 +72,14 @@ class Database(fixtures.Fixture):
         self.engine = db_session.get_engine()
         self.engine.dispose()
         conn = self.engine.connect()
+        # FIXME(stephenfin): This is an issue. We're not applying our
+        # migrations on SQLite in-memory backends and because the model schemas
+        # and migration schemas don't currently match exactly, we are not
+        # testing against something resembling what our customers would see.
+        # We should (a) start applying the migrations for all backends (which
+        # will require reworking the migrations since SQLite doesn't support
+        # ALTER fully, meaning batch mode must be used) and (b) get the two
+        # different sets of schemas in sync and keep them in sync.
         if sql_connection == "sqlite://":
             self.setup_sqlite(db_migrate)
         else:
@@ -86,7 +96,7 @@ class Database(fixtures.Fixture):
             shutil.copyfile(testdb, cleandb)
 
     def setUp(self):
-        super(Database, self).setUp()
+        super().setUp()
         if self.sql_connection == "sqlite://":
             conn = self.engine.connect()
             conn.connection.executescript(self._DB)
@@ -104,6 +114,115 @@ class Database(fixtures.Fixture):
         db_migrate.stamp('head')
 
 
+class WarningsFixture(fixtures.Fixture):
+    """Filters out warnings during test runs."""
+
+    def setUp(self):
+        super().setUp()
+
+        self._original_warning_filters = warnings.filters[:]
+
+        # NOTE(sdague): Make deprecation warnings only happen once. Otherwise
+        # this gets kind of crazy given the way that upstream python libs use
+        # this.
+        warnings.simplefilter('once', DeprecationWarning)
+
+        # NOTE(sdague): this remains an unresolved item around the way
+        # forward on is_admin, the deprecation is definitely really premature.
+        warnings.filterwarnings(
+            'ignore',
+            message=(
+                'Policy enforcement is depending on the value of is_admin. '
+                'This key is deprecated. Please update your policy '
+                'file to use the standard policy values.'
+            ),
+        )
+
+        # NOTE(mriedem): Ignore scope check UserWarnings from oslo.policy.
+        warnings.filterwarnings(
+            'ignore',
+            message='Policy .* failed scope check',
+            category=UserWarning,
+        )
+
+        # NOTE(gibi): The UUIDFields emits a warning if the value is not a
+        # valid UUID. Let's escalate that to an exception in the test to
+        # prevent adding violations.
+        warnings.filterwarnings('error', message='.*invalid UUID.*')
+
+        # NOTE(mriedem): Avoid adding anything which tries to convert an
+        # object to a primitive which jsonutils.to_primitive() does not know
+        # how to handle (or isn't given a fallback callback).
+        warnings.filterwarnings(
+            'error',
+            message=(
+                'Cannot convert <oslo_db.sqlalchemy.enginefacade._Default '
+                'object at '
+            ),
+            category=UserWarning,
+        )
+
+        # Enable deprecation warnings for manila itself to capture upcoming
+        # SQLAlchemy changes
+
+        warnings.filterwarnings(
+            'ignore',
+            category=sqla_exc.SADeprecationWarning,
+        )
+
+        warnings.filterwarnings(
+            'error',
+            module='manila',
+            category=sqla_exc.SADeprecationWarning,
+        )
+
+        # ..but filter everything out until we get around to fixing them
+        # TODO(stephenfin): Fix all of these
+
+        warnings.filterwarnings(
+            'ignore',
+            module='manila',
+            message='Using strings to indicate column or relationship paths ',
+            category=sqla_exc.SADeprecationWarning,
+        )
+
+        warnings.filterwarnings(
+            'ignore',
+            module='manila',
+            message='The current statement is being autocommitted ',
+            category=sqla_exc.SADeprecationWarning,
+        )
+
+        warnings.filterwarnings(
+            'ignore',
+            module='manila',
+            message='The autoload parameter is deprecated ',
+            category=sqla_exc.SADeprecationWarning,
+        )
+
+        warnings.filterwarnings(
+            'ignore',
+            module='manila',
+            message='Using strings to indicate relationship names in Query',
+            category=sqla_exc.SADeprecationWarning,
+        )
+
+        # Enable general SQLAlchemy warnings also to ensure we're not doing
+        # silly stuff. It's possible that we'll need to filter things out here
+        # with future SQLAlchemy versions, but that's a good thing
+
+        warnings.filterwarnings(
+            'error',
+            module='manila',
+            category=sqla_exc.SAWarning,
+        )
+
+        self.addCleanup(self._reset_warning_filters)
+
+    def _reset_warning_filters(self):
+        warnings.filters[:] = self._original_warning_filters
+
+
 class TestCase(base_test.BaseTestCase):
     """Test case base class for all unit tests."""
 
@@ -116,7 +235,7 @@ class TestCase(base_test.BaseTestCase):
 
         global _DB_CACHE
         if not _DB_CACHE:
-            _DB_CACHE = Database(
+            _DB_CACHE = DatabaseFixture(
                 db_api,
                 migration,
                 sql_connection=CONF.database.connection,
@@ -125,6 +244,9 @@ class TestCase(base_test.BaseTestCase):
             )
         self.useFixture(_DB_CACHE)
 
+        # NOTE(stephenfin): WarningsFixture must be after the DatabaseFixture
+        self.useFixture(WarningsFixture())
+
         self.injected = []
         self._services = []
         self.flags(fatal_exception_format_errors=True)
