@@ -17,11 +17,14 @@
 Tests for database migrations.
 """
 
+from unittest import mock
+
 from alembic import script
-import mock
-from oslo_db.sqlalchemy import test_base
+from oslo_db.sqlalchemy import enginefacade
+from oslo_db.sqlalchemy import test_fixtures
 from oslo_db.sqlalchemy import test_migrations
 from oslo_log import log
+from oslotest import base as test_base
 from sqlalchemy.sql import text
 
 from manila.db.migrations.alembic import migration
@@ -35,6 +38,10 @@ class ManilaMigrationsCheckers(test_migrations.WalkVersionsMixin,
                                migrations_data_checks.DbMigrationsData):
     """Test alembic migrations."""
 
+    def setUp(self):
+        super().setUp()
+        self.engine = enginefacade.writer.get_engine()
+
     @property
     def snake_walk(self):
         return True
@@ -139,13 +146,13 @@ class ManilaMigrationsCheckers(test_migrations.WalkVersionsMixin,
                                         'exception': e})
             raise
 
-    # NOTE(vponomaryov): set 7 minutes timeout for case of running it on
+    # NOTE(vponomaryov): set 12 minutes timeout for case of running it on
     # very slow nodes/VMs. Note, that this test becomes slower with each
     # addition of new DB migration. On fast nodes it can take about 5-10 secs
     # having Mitaka set of migrations.
     # 'pymysql' works much slower on slow nodes than 'psycopg2'. And such
     # timeout mostly required for testing of 'mysql' backend.
-    @test_utils.set_timeout(420)
+    @test_utils.set_timeout(720)
     def test_walk_versions(self):
         """Walks all version scripts for each tested database.
 
@@ -167,9 +174,13 @@ class ManilaMigrationsCheckers(test_migrations.WalkVersionsMixin,
                          "Db migrations should have only one branch.")
 
 
-class TestManilaMigrationsMySQL(ManilaMigrationsCheckers,
-                                test_base.MySQLOpportunisticTestCase):
+class TestManilaMigrationsMySQL(
+    ManilaMigrationsCheckers,
+    test_fixtures.OpportunisticDBTestMixin,
+    test_base.BaseTestCase,
+):
     """Run migration tests on MySQL backend."""
+    FIXTURE = test_fixtures.MySQLOpportunisticFixture
 
     @test_utils.set_timeout(300)
     def test_mysql_innodb(self):
@@ -203,5 +214,9 @@ class TestManilaMigrationsMySQL(ManilaMigrationsCheckers,
 
 
 class TestManilaMigrationsPostgreSQL(
-        ManilaMigrationsCheckers, test_base.PostgreSQLOpportunisticTestCase):
+    ManilaMigrationsCheckers,
+    test_fixtures.OpportunisticDBTestMixin,
+    test_base.BaseTestCase,
+):
     """Run migration tests on PostgreSQL backend."""
+    FIXTURE = test_fixtures.PostgresqlOpportunisticFixture
