@@ -47,6 +47,7 @@ SERVICE_STATES_NO_POOLS = {
                   total_capacity_gb=512, free_capacity_gb=200,
                   timestamp=None, reserved_percentage=0,
                   reserved_snapshot_percentage=0,
+                  reserved_share_extend_percentage=0,
                   provisioned_capacity_gb=312,
                   max_over_subscription_ratio=1.0,
                   thin_provisioning=False,
@@ -59,6 +60,7 @@ SERVICE_STATES_NO_POOLS = {
                         total_capacity_gb=256, free_capacity_gb=100,
                         timestamp=None, reserved_percentage=0,
                         reserved_snapshot_percentage=0,
+                        reserved_share_extend_percentage=0,
                         provisioned_capacity_gb=400,
                         max_over_subscription_ratio=2.0,
                         thin_provisioning=True,
@@ -71,6 +73,7 @@ SERVICE_STATES_NO_POOLS = {
                         total_capacity_gb=10000, free_capacity_gb=700,
                         timestamp=None, reserved_percentage=0,
                         reserved_snapshot_percentage=0,
+                        reserved_share_extend_percentage=0,
                         provisioned_capacity_gb=50000,
                         max_over_subscription_ratio=20.0,
                         thin_provisioning=True,
@@ -107,6 +110,7 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
     'host1@AAA': dict(share_backend_name='AAA',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
+                      reserved_share_extend_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -117,12 +121,14 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   free_capacity_gb=41,
                                   reserved_percentage=0,
                                   reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=10,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False)]),
     'host2@BBB': dict(share_backend_name='BBB',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
+                      reserved_share_extend_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -133,12 +139,14 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   free_capacity_gb=42,
                                   reserved_percentage=0,
                                   reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=60,
                                   max_over_subscription_ratio=2.0,
                                   thin_provisioning=True)]),
     'host3@CCC': dict(share_backend_name='CCC',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
+                      reserved_share_extend_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -149,12 +157,14 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   free_capacity_gb=43,
                                   reserved_percentage=0,
                                   reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=20.0,
                                   thin_provisioning=True)]),
     'host4@DDD': dict(share_backend_name='DDD',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
+                      reserved_share_extend_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -165,6 +175,7 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   free_capacity_gb=441,
                                   reserved_percentage=0,
                                   reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=800,
                                   max_over_subscription_ratio=2.0,
                                   thin_provisioning=True),
@@ -173,12 +184,14 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   free_capacity_gb=442,
                                   reserved_percentage=0,
                                   reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=2000,
                                   max_over_subscription_ratio=10.0,
                                   thin_provisioning=True)]),
     'host5@EEE': dict(share_backend_name='EEE',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
+                      reserved_share_extend_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -189,6 +202,7 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   free_capacity_gb=451,
                                   reserved_percentage=0,
                                   reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False),
@@ -197,12 +211,14 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   free_capacity_gb=452,
                                   reserved_percentage=0,
                                   reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False)]),
     'host6@FFF': dict(share_backend_name='FFF',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
+                      reserved_share_extend_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -213,6 +229,7 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   free_capacity_gb='unknown',
                                   reserved_percentage=0,
                                   reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False),
@@ -221,11 +238,172 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   free_capacity_gb='unknown',
                                   reserved_percentage=0,
                                   reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False)]),
 }
 
+FAKE_ACTIVE_IQ_WEIGHER_LIST = [
+    "fake_aggregate_1:fake_cluster_name1",
+    "fake_aggregate_2:fake_cluster_name2",
+    "fake_aggregate_3:fake_cluster_name3"
+]
+
+FAKE_ACTIVE_IQ_WEIGHER_AGGREGATES_RESPONSE = {
+    "records": [
+        {
+            "name": "fake_aggregate_1",
+            "key": "fake_key_1",
+            "cluster": {
+                "name": "fake_cluster_name1"
+            }
+        },
+        {
+            "name": "fake_aggregate_2",
+            "key": "fake_key_2",
+            "cluster": {
+                "name": "fake_cluster_name2"
+            }
+        },
+        {
+            "name": "fake_aggregate_3",
+            "key": "fake_key_3",
+            "cluster": {
+                "name": "fake_cluster_name3"
+            }
+        }
+    ]
+}
+
+FAKE_ACTIVE_IQ_WEIGHER_BALANCE_RESPONSE = [
+    {
+        "key": "fake_key_1",
+        "scores": {
+            "total_weighted_score": 10.0
+        }
+    },
+    {
+        "key": "fake_key_2",
+        "scores": {
+            "total_weighted_score": 20.0
+        }
+    }
+]
+
+
+class FakeHostManagerNetAppOnly(host_manager.HostManager):
+    def __init__(self):
+        super(FakeHostManagerNetAppOnly, self).__init__()
+
+        self.service_states = {
+            'host1': {
+                'total_capacity_gb': 1024,
+                'free_capacity_gb': 1024,
+                'allocated_capacity_gb': 0,
+                'thin_provisioning': False,
+                'reserved_percentage': 10,
+                'reserved_snapshot_percentage': 5,
+                'reserved_share_extend_percentage': 15,
+                'timestamp': None,
+                'snapshot_support': True,
+                'create_share_from_snapshot_support': True,
+                'replication_type': 'writable',
+                'replication_domain': 'endor',
+                'storage_protocol': 'NFS_CIFS',
+                'vendor_name': 'NetApp',
+                'netapp_cluster_name': 'cluster1',
+            },
+            'host2': {
+                'total_capacity_gb': 2048,
+                'free_capacity_gb': 300,
+                'allocated_capacity_gb': 1748,
+                'provisioned_capacity_gb': 1748,
+                'max_over_subscription_ratio': 2.0,
+                'thin_provisioning': True,
+                'reserved_percentage': 10,
+                'reserved_snapshot_percentage': 5,
+                'reserved_share_extend_percentage': 15,
+                'timestamp': None,
+                'snapshot_support': True,
+                'create_share_from_snapshot_support': True,
+                'replication_type': 'readable',
+                'replication_domain': 'kashyyyk',
+                'storage_protocol': 'NFS_CIFS',
+                'vendor_name': 'NetApp',
+                'netapp_cluster_name': 'cluster2',
+            },
+            'host3': {
+                'total_capacity_gb': 512,
+                'free_capacity_gb': 256,
+                'allocated_capacity_gb': 256,
+                'provisioned_capacity_gb': 256,
+                'max_over_subscription_ratio': 2.0,
+                'thin_provisioning': [False],
+                'reserved_percentage': 0,
+                'reserved_snapshot_percentage': 0,
+                'reserved_share_extend_percentage': 0,
+                'snapshot_support': True,
+                'create_share_from_snapshot_support': True,
+                'timestamp': None,
+                'storage_protocol': 'NFS_CIFS',
+                'vendor_name': 'NetApp',
+                'netapp_cluster_name': 'cluster3',
+            },
+            'host4': {
+                'total_capacity_gb': 2048,
+                'free_capacity_gb': 200,
+                'allocated_capacity_gb': 1848,
+                'provisioned_capacity_gb': 1848,
+                'max_over_subscription_ratio': 1.0,
+                'thin_provisioning': [True],
+                'reserved_percentage': 5,
+                'reserved_snapshot_percentage': 2,
+                'reserved_share_extend_percentage': 5,
+                'timestamp': None,
+                'snapshot_support': True,
+                'create_share_from_snapshot_support': True,
+                'replication_type': 'dr',
+                'replication_domain': 'naboo',
+                'storage_protocol': 'NFS_CIFS',
+                'vendor_name': 'NetApp',
+                'netapp_cluster_name': 'cluster4',
+            },
+            'host5': {
+                'total_capacity_gb': 2048,
+                'free_capacity_gb': 500,
+                'allocated_capacity_gb': 1548,
+                'provisioned_capacity_gb': 1548,
+                'max_over_subscription_ratio': 1.5,
+                'thin_provisioning': [True, False],
+                'reserved_percentage': 5,
+                'reserved_snapshot_percentage': 2,
+                'reserved_share_extend_percentage': 5,
+                'timestamp': None,
+                'snapshot_support': True,
+                'create_share_from_snapshot_support': True,
+                'replication_type': None,
+                'storage_protocol': 'NFS_CIFS',
+                'vendor_name': 'NetApp',
+                'netapp_cluster_name': 'cluster5',
+            },
+            'host6': {
+                'total_capacity_gb': 'unknown',
+                'free_capacity_gb': 'unknown',
+                'allocated_capacity_gb': 1548,
+                'thin_provisioning': False,
+                'reserved_percentage': 5,
+                'reserved_snapshot_percentage': 2,
+                'reserved_share_extend_percentage': 5,
+                'snapshot_support': True,
+                'create_share_from_snapshot_support': True,
+                'timestamp': None,
+                'storage_protocol': 'GLUSTERFS',
+                'vendor_name': 'NetApp',
+                'netapp_cluster_name': 'cluster6',
+            },
+        }
+
 
 class FakeFilterScheduler(filter.FilterScheduler):
     def __init__(self, *args, **kwargs):
@@ -244,12 +422,14 @@ class FakeHostManager(host_manager.HostManager):
                       'thin_provisioning': False,
                       'reserved_percentage': 10,
                       'reserved_snapshot_percentage': 5,
+                      'reserved_share_extend_percentage': 15,
                       'timestamp': None,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'replication_type': 'writable',
                       'replication_domain': 'endor',
                       'storage_protocol': 'NFS_CIFS',
+                      'vendor_name': 'Dummy',
                       },
             'host2': {'total_capacity_gb': 2048,
                       'free_capacity_gb': 300,
@@ -259,12 +439,14 @@ class FakeHostManager(host_manager.HostManager):
                       'thin_provisioning': True,
                       'reserved_percentage': 10,
                       'reserved_snapshot_percentage': 5,
+                      'reserved_share_extend_percentage': 15,
                       'timestamp': None,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'replication_type': 'readable',
                       'replication_domain': 'kashyyyk',
                       'storage_protocol': 'NFS_CIFS',
+                      'vendor_name': 'Dummy',
                       },
             'host3': {'total_capacity_gb': 512,
                       'free_capacity_gb': 256,
@@ -274,10 +456,12 @@ class FakeHostManager(host_manager.HostManager):
                       'thin_provisioning': [False],
                       'reserved_percentage': 0,
                       'reserved_snapshot_percentage': 0,
+                      'reserved_share_extend_percentage': 0,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'timestamp': None,
                       'storage_protocol': 'NFS_CIFS',
+                      'vendor_name': 'Dummy',
                       },
             'host4': {'total_capacity_gb': 2048,
                       'free_capacity_gb': 200,
@@ -287,12 +471,14 @@ class FakeHostManager(host_manager.HostManager):
                       'thin_provisioning': [True],
                       'reserved_percentage': 5,
                       'reserved_snapshot_percentage': 2,
+                      'reserved_share_extend_percentage': 5,
                       'timestamp': None,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'replication_type': 'dr',
                       'replication_domain': 'naboo',
                       'storage_protocol': 'NFS_CIFS',
+                      'vendor_name': 'Dummy',
                       },
             'host5': {'total_capacity_gb': 2048,
                       'free_capacity_gb': 500,
@@ -302,11 +488,13 @@ class FakeHostManager(host_manager.HostManager):
                       'thin_provisioning': [True, False],
                       'reserved_percentage': 5,
                       'reserved_snapshot_percentage': 2,
+                      'reserved_share_extend_percentage': 5,
                       'timestamp': None,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'replication_type': None,
                       'storage_protocol': 'NFS_CIFS',
+                      'vendor_name': 'Dummy',
                       },
             'host6': {'total_capacity_gb': 'unknown',
                       'free_capacity_gb': 'unknown',
@@ -314,10 +502,12 @@ class FakeHostManager(host_manager.HostManager):
                       'thin_provisioning': False,
                       'reserved_percentage': 5,
                       'reserved_snapshot_percentage': 2,
+                      'reserved_share_extend_percentage': 5,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'timestamp': None,
                       'storage_protocol': 'GLUSTERFS',
+                      'vendor_name': 'Dummy',
                       },
         }
 
