@@ -18,7 +18,6 @@ import random
 from unittest import mock
 
 import ddt
-import six
 
 from manila.common import constants
 from manila import context
@@ -771,7 +770,7 @@ class ShareInstanceAccessTestCase(test.TestCase):
         self.assertEqual(fake_expect_driver_update_rules, driver_update_rules)
 
     def _get_pass_rules_and_fail_rules(self):
-        random_value = six.text_type(random.randint(10, 32))
+        random_value = str(random.randint(10, 32))
         pass_rules = [
             {
                 'access_type': 'ip',
@@ -797,3 +796,56 @@ class ShareInstanceAccessTestCase(test.TestCase):
             },
         ]
         return pass_rules, fail_rules
+
+    def test_update_share_instances_access_rules_status(self):
+        mock_db_instances_update = self.mock_object(
+            db, 'share_instances_status_update')
+        share_instances = ['fake_instance_id', 'fake_instance_id_2']
+
+        self.access_helper.update_share_instances_access_rules_status(
+            self.context, 'fake_status', share_instances)
+
+        mock_db_instances_update.assert_called_once_with(
+            self.context, share_instances,
+            {'access_rules_status': 'fake_status'})
+
+    @ddt.data(True, False)
+    def test_reset_rules_to_queueing_states(self, reset_active):
+        share = db_utils.create_share(
+            status=constants.STATUS_AVAILABLE,
+            # if rules are applying/denying, status would be 'syncing', but,
+            # lets test the transition to syncing when asked to reset_active
+            access_rules_status=constants.STATUS_ACTIVE)
+        share_instance_id = share['instance']['id']
+        rule_kwargs = {'share_id': share['id'], 'access_level': 'rw'}
+        r1 = db_utils.create_access(
+            state=constants.ACCESS_STATE_APPLYING, **rule_kwargs)
+        r2 = db_utils.create_access(
+            state=constants.ACCESS_STATE_DENYING, **rule_kwargs)
+        r3 = db_utils.create_access(
+            state=constants.ACCESS_STATE_ACTIVE, **rule_kwargs)
+        r4 = db_utils.create_access(
+            state=constants.ACCESS_STATE_ACTIVE, **rule_kwargs)
+
+        self.access_helper.reset_rules_to_queueing_states(
+            self.context, share_instance_id, reset_active=reset_active)
+
+        rules = db.share_access_get_all_for_instance(
+            self.context, share_instance_id)
+        share_instance = db.share_instance_get(self.context, share_instance_id)
+        rules_dict = {r['access_id']: r for r in rules}
+        self.assertEqual(constants.SHARE_INSTANCE_RULES_SYNCING,
+                         share_instance['access_rules_status'])
+        self.assertEqual(constants.ACCESS_STATE_QUEUED_TO_APPLY,
+                         rules_dict[r1['id']]['state'])
+        self.assertEqual(constants.ACCESS_STATE_QUEUED_TO_DENY,
+                         rules_dict[r2['id']]['state'])
+        expected_state_for_previously_active = (
+            constants.ACCESS_STATE_QUEUED_TO_APPLY
+            if reset_active else
+            constants.ACCESS_STATE_ACTIVE
+        )
+        self.assertEqual(expected_state_for_previously_active,
+                         rules_dict[r3['id']]['state'])
+        self.assertEqual(expected_state_for_previously_active,
+                         rules_dict[r4['id']]['state'])
