@@ -235,6 +235,15 @@ class ShareRpcAPITestCase(test.TestCase):
                              rpc_method='cast',
                              share_server=self.fake_share_server)
 
+    def test_transfer_accept(self):
+        self._test_share_api('transfer_accept',
+                             rpc_method='call',
+                             version='1.25',
+                             share=self.fake_share,
+                             new_user='new_user',
+                             new_project='new_project',
+                             clear_rules=False)
+
     def test_extend_share(self):
         self._test_share_api('extend_share',
                              rpc_method='cast',
@@ -330,8 +339,9 @@ class ShareRpcAPITestCase(test.TestCase):
     def test_promote_share_replica(self):
         self._test_share_api('promote_share_replica',
                              rpc_method='cast',
-                             version='1.8',
-                             share_replica=self.fake_share_replica)
+                             version='1.24',
+                             share_replica=self.fake_share_replica,
+                             quiesce_wait_time=None)
 
     def test_update_share_replica(self):
         self._test_share_api('update_share_replica',
